#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
PURPOSE: For testing meetup models
AUTHOR: dylangregersen
DATE: Mon Sep 15 00:52:58 2014
"""
# ########################################################################### #

# import modules 

from __future__ import print_function, division, unicode_literals
import os 
import unittest
from django.conf import settings
from meetup.api import MeetupClient

MEETUP_KEY =  settings.MEETUP_KEY

# ########################################################################### #


# TODO: implement tests

def test_basic_invoke ():
    """ make sure the invoke returns correct objects """
    pass
        
pass 
# ########################################################################### #
if __name__ == "__main__":
    pass
    
