#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
PURPOSE: For testing meetup models
AUTHOR: dylangregersen
DATE: Mon Sep 15 00:52:58 2014
"""
# ########################################################################### #

# import modules 

from __future__ import print_function, division, unicode_literals
import os 
from meetup.models import Event,Group,Venue,Member
import unittest

# ########################################################################### #


# TODO: implement tests

def test_Event_meetup_data_to_kws ():
    # one for Event,Group,Venue,Member
    pass
    
def test_Event_object_to_meetup_data ():
    # one for Event,Group,Venue,Member
    pass
        
pass 
# ########################################################################### #
if __name__ == "__main__":
    pass
    
